#[repr(transparent)]pub struct RoomHistory {
inner: TypedObjectRef<RoomHistory, <RoomHistory as ObjectSubclass>::ParentType>,
phantom: PhantomData<()>,
}Expand description
A view that displays the timeline of a room and ways to send new messages.
GLib type: GObject with reference counted clone semantics.
Fields
inner: TypedObjectRef<RoomHistory, <RoomHistory as ObjectSubclass>::ParentType>phantom: PhantomData<()>Implementations
Sourceimpl RoomHistory
impl RoomHistory
Sourcepub fn timeline(&self) -> <BoundObject<Timeline> as Property>::Value
pub fn timeline(&self) -> <BoundObject<Timeline> as Property>::Value
The timeline currently displayed.
Sourcepub fn set_timeline<'a>(
&self,
value: Option<impl Borrow<<<BoundObject<Timeline> as Property>::Value as HasParamSpec>::SetValue>>,
)
pub fn set_timeline<'a>( &self, value: Option<impl Borrow<<<BoundObject<Timeline> as Property>::Value as HasParamSpec>::SetValue>>, )
The timeline currently displayed.
Sourcepub fn is_only_view(&self) -> <Cell<bool> as Property>::Value
pub fn is_only_view(&self) -> <Cell<bool> as Property>::Value
Whether this is the only view visible, i.e. there is no sidebar.
Sourcepub fn set_is_only_view<'a>(
&self,
value: impl Borrow<<<Cell<bool> as Property>::Value as HasParamSpec>::SetValue>,
)
pub fn set_is_only_view<'a>( &self, value: impl Borrow<<<Cell<bool> as Property>::Value as HasParamSpec>::SetValue>, )
Whether this is the only view visible, i.e. there is no sidebar.
Sourcepub fn is_sticky(&self) -> <Cell<bool> as Property>::Value
pub fn is_sticky(&self) -> <Cell<bool> as Property>::Value
Whether the room history should stick to the newest message in the timeline.
Sourcepub fn connect_timeline_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_timeline_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the timeline property
Sourcepub fn connect_is_only_view_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_is_only_view_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the is-only-view property
Sourcepub fn connect_is_sticky_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_is_sticky_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the is-sticky property
Sourcepub fn notify_timeline(&self)
pub fn notify_timeline(&self)
Notify listeners of a change in the timeline property
Sourcepub fn notify_is_only_view(&self)
pub fn notify_is_only_view(&self)
Notify listeners of a change in the is-only-view property
Sourcepub fn notify_is_sticky(&self)
pub fn notify_is_sticky(&self)
Notify listeners of a change in the is-sticky property
Sourceimpl RoomHistory
impl RoomHistory
pub fn new() -> Self
Sourcepub(crate) fn header_bar(&self) -> &HeaderBar
pub(crate) fn header_bar(&self) -> &HeaderBar
The header bar of the room history.
Sourcepub(super) fn message_toolbar(&self) -> &MessageToolbar
pub(super) fn message_toolbar(&self) -> &MessageToolbar
The message toolbar of the room history.
Sourcepub(crate) fn enable_sticky_mode(&self, enable: bool)
pub(crate) fn enable_sticky_mode(&self, enable: bool)
Enable or disable the mode allowing the room history to stick to the bottom based on scrollbar position.
Sourcepub(crate) fn handle_paste_action(&self)
pub(crate) fn handle_paste_action(&self)
Handle a paste action.
The context menu for rows presenting an Event.